@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
- *
- * Author:     Ji XiangLong <jixianglong@uniontech.com>
- *
- * Maintainer: WangYu <wangyu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2020 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "clefttoolbar.h"
 #include "utils/baseutils.h"
 #include "drawTools/cdrawtoolfactory.h"
@@ -47,6 +31,7 @@ DGUI_USE_NAMESPACE
 
 const int BTN_SPACING = 12;
 bool blocked = false;
+const int TOOL_MANAGER_WIDTH = 68;
 
 DrawToolManager::DrawToolManager(DrawBoard *parent)
     : DFrame(parent), m_drawBoard(parent)
@@ -204,7 +189,7 @@ void DrawToolManager::initUI()
     this->setAutoFillBackground(true);
 
     setMinimumHeight(460);//设置最小高度保证最小化显示正常
-    setFixedWidth(58);
+    setFixedWidth(TOOL_MANAGER_WIDTH);
 
     auto mainLayout = new QVBoxLayout(this);
     mainLayout->setContentsMargins(0, 0, 0, 0);
