@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2020 - 2022 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2020 - 2023 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -9,32 +9,16 @@
 #include <gmock/gmock-matchers.h>
 #define protected public
 #define private public
-#include "cgraphicsview.h"
+//#include "cgraphicsview.h"
 #include <QtTest>
 #include <QTestEventList>
 #include <qaction.h>
 
-
-
 #include "mainwindow.h"
-#include "ccentralwidget.h"
-#include "application.h"
-#include "cgraphicsview.h"
-#include "clefttoolbar.h"
-#include "toptoolbar.h"
-#include "cdrawscene.h"
-
-#include "cpictureitem.h"
-#include "cgraphicsrectitem.h"
-#include "cgraphicsellipseitem.h"
-#include "cgraphicstriangleitem.h"
-#include "cgraphicspolygonalstaritem.h"
-#include "cgraphicspolygonitem.h"
-#include "cgraphicslineitem.h"
-#include "cgraphicspenitem.h"
-#include "cgraphicstextitem.h"
-#include "cgraphicscutitem.h"
-#include "cgraphicsitemselectedmgr.h"
+#include "pageview.h"
+#include "pageitem.h"
+#include "pagescene.h"
+#include "globaldefine.h"
 
 #include <DComboBox>
 #include <DLineEdit>
@@ -42,12 +26,12 @@
 #include <DSlider>
 
 #include "calphacontrolwidget.h"
-#include <dzoommenucombobox.h>
+//#include <dzoommenucombobox.h>
 #include "cspinbox.h"
-#include "ccolorpickwidget.h"
+//#include "ccolorpickwidget.h"
 #include "ciconbutton.h"
-#include "cgraphicsitem.h"
-#include "pickcolorwidget.h"
+//#include "cgraphicsitem.h"
+//#include "pickcolorwidget.h"
 
 #include <QBrush>
 #undef protected
@@ -97,11 +81,11 @@ private:
 
 void createNewViewByShortcutKey();
 
-void setPenWidth(CGraphicsItem *item, int width);
+void setPenWidth(PageItem *item, int width);
 
-void setStrokeColor(CGraphicsItem *item, QColor color);
+void setStrokeColor(PageItem *item, QColor color);
 
-void setBrushColor(CGraphicsItem *item, QColor color);
+void setBrushColor(PageItem *item, QColor color);
 
 void resizeItem();
 
@@ -115,7 +99,7 @@ void createItemWithkeyShift(PageView *view, bool altCopyItem = true, QPoint star
 
 void keyShortCutCopyItem(int addTimes = 1);
 
-QList<CGraphicsItem *> currentSceneBzItems(PageScene::ESortItemTp sortTp = PageScene::EDesSort);
+QList<PageItem *> currentSceneBzItems(ESortItemTp sortTp = EDesSort);
 int                    currentSceneBzCount();
 
 void layerChange();
